This is a collection of tools, common things used by packages of material science.



Vis:

Contain a collection of matplotlib, pyplot, gnuplot methods 
used for ploting common results from material science simulations.



Feel free to contribute


Intall


in the future:
pip install plot_methods
